@@ -8,24 +8,28 @@
  * \author John Levon
  * \author Angus Leeming
  *
- * Full author contact details are available in file CREDITS
+ * Full author contact details are available in file CREDITS.
  */
 
 #ifndef FORM_MATHSDELIM_H
 #define FORM_MATHSDELIM_H
 
-#include "FormBase.h"
+#include "FormDialogView.h"
 
-class ControlMathSub;
+namespace lyx {
+namespace frontend {
+
+class ControlMath;
 struct FD_maths_delim;
 
 /**
  * This class provides an XForms implementation of the maths delim.
  */
-class FormMathsDelim : public FormCB<ControlMathSub, FormDB<FD_maths_delim> > {
+class FormMathsDelim
+	: public FormController<ControlMath, FormView<FD_maths_delim> > {
 public:
 	///
-	FormMathsDelim();
+	FormMathsDelim(Dialog &);
 
 private:
 	///
@@ -36,6 +40,11 @@ private:
 	virtual ButtonPolicy::SMInput input(FL_OBJECT *, long);
 	///
 	virtual void update();
+	/// size of delimiters
+	int size_;
 };
 
+} // namespace frontend
+} // namespace lyx
+
 #endif //  FORM_MATHSDELIM_H
